@@ -9,6 +9,7 @@ BUILD_DIR = '_build'
 # exclude these directories and files
 EXCLUDED = (
     '_build',
+    '.sass-cache',
     'layout.html',
     '.DS_Store',
     'conf.py',
@@ -17,6 +18,7 @@ EXCLUDED = (
 # which extentions to renderr?
 EXTENTIONS = (
     '.html',
+    '.css',
 )
 # the blocks to parse for code and markdown
 CONTENT_BLOCK = 'content'
